@@ -149,15 +149,16 @@ class Patch:
         "Returns the absolute path of the backup file"
         return f'{self.__hop_cls.project_path}/Backups/{self.dbname}-{release_s}.sql'
 
-    def save_database(self):
-        """Dumps the database"""
+    def save_database(self, force=False):
+        """Dumps the database 
+        """
         if not os.path.isdir('./Backups'):
             os.mkdir('./Backups')
         svg_file = self.__backup_path(self.__last_release_s)
-        if os.path.isfile(svg_file):
+        if os.path.isfile(svg_file) and not force:
             sys.stderr.write(
                 f"Oops! there is already a dump for the {self.__last_release_s} release.\n")
-            sys.stderr.write(f"Please remove {svg_file} if you realy want to proceed.\n")
+            sys.stderr.write(f"Please use the --force option if you realy want to proceed.\n")
             sys.exit(1)
         subprocess.run(['pg_dump', self.dbname, '-f', svg_file], check=True)
 
@@ -168,9 +169,9 @@ class Patch:
         self.get_next_release(last_release)
         if self.__release_s == '':
             return
+        # we've got a patch we switch to a new branch
         self.__hgit.set_branch(self.__release_s)
-        # we got a patch we switch to a new branch
-        self.save_database()
+        self.save_database(force)
         if not os.path.exists(self.__patch_path):
             sys.stderr.write(f'The directory {self.__patch_path} does not exists!\n')
             sys.exit(1)
@@ -241,12 +242,34 @@ class Patch:
         """
         return next(self.model.get_relation_class('half_orm_meta.view.hop_last_release')().select())
 
-    @classmethod
     def get_release_s(cls, release):
         """Returns the current release (str)
         """
         return '{major}.{minor}.{patch}'.format(**release)
 
+    def prep_next_release(self, release_level):
+        """Returns the next (major, minor, patch) tuple according to the release_level
+
+        Args:
+            release_level (str): one of ['patch', 'minor', 'major']
+        """
+        current = self.get_current_release()
+        next = {}
+        next['major'] = current['major']
+        next['minor'] = current['minor']
+        next['patch'] = current['patch']
+        next[release_level] = next[release_level] + 1
+        if release_level == 'major':
+            next['minor'] = next['patch'] = 0
+        if release_level == 'minor':
+            next['patch'] = 0
+        patch_path = 'Patches/{major}/{minor}/{patch}'.format(**next)
+        if not os.path.exists(patch_path):
+            changelog_msg = input('CHANGELOG message: ')
+            os.makedirs(patch_path)
+            with open(f'{patch_path}/CHANGELOG.md', 'w', encoding='utf-8') as changelog:
+                changelog.write(changelog_msg)
+
     def get_next_release(self, last_release=None):
         "Renvoie en fonction de part le numéro de la prochaine release"
         if last_release is None:
